@@ -1,12 +1,12 @@
 --
--- (C) 2013-18 - ntop.org
+-- (C) 2013-20 - ntop.org
 --
 
 --
 -- This script is executed once at startup similar to /etc/rc.local on Unix
 --
 
-dirs = ntop.getDirs()
+local dirs = ntop.getDirs()
 package.path = dirs.installdir .. "/scripts/lua/modules/?.lua;" .. package.path
 
 if(ntop.isPro()) then
@@ -15,48 +15,45 @@ if(ntop.isPro()) then
 end
 
 require "lua_utils"
-require "alert_utils"
+
+-- Important: load this before any other alert related module
+local plugins_utils = require "plugins_utils"
+plugins_utils.loadPlugins()
+
+local recipients = require "recipients"
+recipients.initialize()
+
+local alert_utils = require "alert_utils"
 
 local discover_utils = require "discover_utils"
-local host_pools_utils = require "host_pools_utils"
+local host_pools_nedge = require "host_pools_nedge"
 local os_utils = require "os_utils"
 local lists_utils = require "lists_utils"
 local recovery_utils = require "recovery_utils"
-
+local delete_data_utils = require "delete_data_utils"
+local ts_utils = require "ts_utils"
+local user_scripts = require("user_scripts")
+local presets_utils = require "presets_utils"
 local prefs = ntop.getPrefs()
+local notification_configs = require "notification_configs"
 
--- restore sticky hosts
-if prefs.sticky_hosts ~= nil then
-   -- if the sticky hosts are set, then we try and restore them out of redis
-   for _, ifname in pairs(interface.getIfNames()) do
-      interface.select(ifname)
-      local ifid = getInterfaceId(ifname)
-      -- an example key is ntopng.serialized_hosts.ifid_6__192.168.2.136@0
-      local keys_pattern = "ntopng.serialized_hosts.ifid_"..ifid.."__*"
-      local dumped_hosts = ntop.getKeysCache("ntopng.serialized_hosts.ifid_"..ifid.."__*")
-
-      if dumped_hosts ~= nil then
-	 for hostkey, _ in pairs(dumped_hosts) do
-	    -- let's extract just the host name and vlan from the whole key;
-	    -- restore host will do the rest ...
-	    local key_parts = string.split(hostkey, "__")
-	    if key_parts ~= nil and key_parts[2] ~= nil then
-	       local hostkey = key_parts[2]
-
-	       interface.restoreHost(hostkey, true --[[ skip privileges checks: no web access --]])
-	    end
-	 end
-      end
-   end
+host_pools_nedge.migrateHostPools()
+if ntop.isnEdge() then
+   host_pools_nedge.initPools()
 end
 
-host_pools_utils.initPools()
-
 if(ntop.isPro()) then
    shaper_utils = require "shaper_utils"
    shaper_utils.initShapers()
 end
 
+traceError(TRACE_NORMAL, TRACE_CONSOLE, "Processing startup.lua: please hold on...")
+
+-- ##################################################################
+
+-- Load the default user scripts configuration
+user_scripts.loadDefaultConfig()
+
 -- Use a specific bridging_policy_target_type default for previous user installations
 if isEmptyString(ntop.getPref("ntopng.prefs.bridging_policy_target_type")) then
    for _, ifname in pairs(interface.getIfNames()) do
@@ -91,43 +88,42 @@ end
 
 -- ##################################################################
 
--- Remove the json dumps previously needed for alerts generation
-for _, ifname in pairs(interface.getIfNames()) do
+local has_pcap_dump_interface = false
+
+local function cleanupIfname(ifname)
    interface.select(ifname)
    local ifid = getInterfaceId(ifname)
 
+   if interface.isPcapDumpInterface() then
+      has_pcap_dump_interface = true
+   end
+
    local alerts_status_path = os_utils.fixPath(dirs.workingdir .. "/" .. ifid .. "/json/")
    ntop.rmdir(alerts_status_path)
 
    -- Remove the active devices and pools keys
-   deleteActiveDevicesKey(ifid)
-   deleteActivePoolsKey(ifid)
+   alert_utils.deleteActiveDevicesKey(ifid)
+   alert_utils.deleteActivePoolsKey(ifid)
 
    -- Remove network discovery request on startup
    discover_utils.clearNetworkDiscovery(ifid)
 
-   -- Note: we do not delete this as quotas are persistent across ntopng restart
-   --deletePoolsQuotaExceededItemsKey(ifid)
-
    -- Clean old InfluxDB export cache
    local export_dir = os_utils.fixPath(dirs.workingdir .. "/".. ifid .."/ts_export")
    ntop.rmdir(export_dir)
 end
 
+-- Remove the json dumps previously needed for alerts generation
+for _, ifname in pairs(interface.getIfNames()) do
+   cleanupIfname(ifname)
+end
+cleanupIfname(getSystemInterfaceName())
+
 -- Also flush the export queue
 ntop.delCache("ntopng.influx_file_queue")
 
 -- ##################################################################
 
--- Initialize device policies (presets)
-local presets_utils = require "presets_utils"
-local ifid, ifname = getFirstInterfaceId()
-interface.select(ifname)
-presets_utils.init()
-presets_utils.reloadAllDevicePolicies()
-
--- ##################################################################
-
 -- Check remote assistance expiration
 local remote_assistance = require "remote_assistance"
 remote_assistance.checkAvailable()
@@ -140,8 +136,20 @@ recording_utils.checkAvailable()
 
 -- ##################################################################
 
-initCustomnDPIProtoCategories()
-lists_utils.reloadLists() -- housekeeping will do the actual reload...
+local companion_interface_utils = require "companion_interface_utils"
+companion_interface_utils.initCompanions()
+
+-- ##################################################################
+
+lists_utils.startup()
+
+-- ##################################################################
+
+-- Initialize device policies (presets)
+-- NOTE: Must go after lists_utils initialization and reload
+-- as new custom protocols can be set by lists utils
+presets_utils.init()
+presets_utils.reloadAllDevicePolicies()
 
 -- TODO: migrate custom re-arm settings
 
@@ -151,8 +159,7 @@ if  ntop.isnEdge() then
    http_bridge_conf_utils.configureBridge()
 end
 
-processAlertNotifications(os.time(), 0, true --[[ force ]])
-notify_ntopng_start()
+alert_utils.notify_ntopng_start()
 
 if not recovery_utils.check_clean_shutdown() then
    package.path = dirs.installdir .. "/scripts/callbacks/system/?.lua;" .. package.path
@@ -160,3 +167,52 @@ if not recovery_utils.check_clean_shutdown() then
 end
 
 recovery_utils.unmark_clean_shutdown()
+
+-- Need to run setup at startup since the schemas may be changed
+ts_utils.setupAgain()
+
+-- Migrate "iface:ndpi_categories" under the correct folder
+if(ntop.getCache("ntopng.cache.rrd_category_migration") ~= "1") then
+   for ifid, ifname in pairs(delete_data_utils.list_all_interfaces()) do
+      ntop.mkdir(dirs.workingdir .. "/" .. ifid .. "/rrd/ndpi_categories")
+
+      for cat_name, cat_id in pairs(interface.getnDPICategories()) do
+         local old_path = os_utils.fixPath(dirs.workingdir .. "/" .. ifid .. "/rrd/"..cat_name..".rrd")
+
+         if ntop.exists(old_path) then
+            local new_path = os_utils.fixPath(dirs.workingdir .. "/" .. ifid .. "/rrd/ndpi_categories/"..cat_name..".rrd")
+
+            traceError(TRACE_INFO, TRACE_CONSOLE, "Migrating Category RRD: " .. old_path)
+            os.rename(old_path, new_path)
+         end
+      end
+   end
+
+   -- do not perform migration again
+   ntop.setCache("ntopng.cache.rrd_category_migration", "1")
+end
+
+-- Clear the unused DHCP cache keys
+for ifid, ifname in pairs(delete_data_utils.list_all_interfaces()) do
+   ntop.delCache("ntopng.dhcp."..ifid..".cache")
+end
+
+if(has_pcap_dump_interface) then
+  -- Load the lists at the very beginning in order to avoid misclassification
+  -- when reading from PCAP dump. This can take some time.
+  traceError(TRACE_NORMAL, TRACE_CONSOLE, "Loading category lists...")
+  lists_utils.checkReloadLists()
+  traceError(TRACE_NORMAL, TRACE_CONSOLE, "Loading category lists done")
+end
+
+-- Show the warning at most 1 time per run
+ntop.delCache("ntopng.cache.rrd_format_change_warning_shown")
+
+-- Check if there is a local file to run
+local local_startup_file = "/usr/share/ntopng/local/scripts/callbacks/system/startup.lua"
+if(ntop.exists(local_startup_file)) then
+   traceError(TRACE_NORMAL, TRACE_CONSOLE, "Running "..local_startup_file)
+   dofile(local_startup_file)
+end
+
+traceError(TRACE_NORMAL, TRACE_CONSOLE, "Startup completed: ntopng is now operational")
