@@ -3,9 +3,9 @@ print [[
   <div class="modal-dialog">
     <div class="modal-content">
       <div class="modal-header">
-  <button type="button" class="close" data-dismiss="modal" aria-hidden="true">x</button>
-  <h3 id="delete_user_dialog_label">]] print(i18n("users.delete_user")) print[[</h3>
-</div>
+        <h5 class='modal-title' id="delete_user_dialog_label">]] print(i18n("users.delete_user")) print[[ <span class="password_dialog_title"></span></h5>
+        <button type="button" class="close" data-dismiss="modal" aria-hidden="true">&times;</button>
+      </div>
 
 <div class="modal-body">
 
@@ -19,9 +19,9 @@ print [[
   delete_user_alert.warning = function(message) { $('#delete_user_alert_placeholder').html('<div class="alert alert-warning">' + message + '</div>'); }
 </script>
 
-  <form id="form_delete_user" class="form-horizontal" method="post" action="delete_user.lua">
+  <form id="form_delete_user" class="form-horizontal" method="post" action="]] print(ntop.getHttpPrefix()) print[[/lua/rest/v1/delete/ntopng/user.lua">
 			      ]]
-print('<input id="csrf" name="csrf" type="hidden" value="'..ntop.getRandomCSRFValue()..'" />\n')
+print('<input name="csrf" type="hidden" value="'..ntop.getRandomCSRFValue()..'" />\n')
 
 local location_href = ntop.getHttpPrefix().."/lua/admin/users.lua"
 
@@ -37,13 +37,14 @@ print [[
       url: frmdeluser.attr('action'),
       data: frmdeluser.serialize(),
       success: function (data) {
-        var response = jQuery.parseJSON(data);
-        if (response.result == 0) {
-          delete_user_alert.success(response.message); 
+        if (data.rc == 0) {
+          delete_user_alert.success(data.rc_str);
           window.location.href = ']] print(location_href) print[[';
         } else {
-          delete_user_alert.error(response.message);
+          delete_user_alert.error(data.rc_str);
         }
+      }, error: function (data) {
+        delete_user_alert.error("]] print(i18n("users.delete_user_error")) print[[");
       }
     });
     return false;
@@ -53,8 +54,7 @@ print [[
 </div> <!-- modal-body -->
 
 <div class="modal-footer">
-  <button class="btn btn-default btn-sm" data-dismiss="modal" aria-hidden="true">]] print(i18n("close")) print[[</button>
-  <button id="delete_user_submit" class="btn btn-danger btn-sm">]] print(i18n("delete")) print[[</button>
+  <button id="delete_user_submit" class="btn btn-danger">]] print(i18n("delete")) print[[</button>
 </div>
 
 <script>
