@@ -25,6 +25,7 @@ local is_admin = isAdministrator()
 local is_windows = ntop.isWindows()
 local info = ntop.getInfo()
 local updates_supported = (is_admin and ntop.isPackage() and not ntop.isWindows())
+local has_local_auth = (ntop.getPref("ntopng.prefs.local.auth_enabled") ~= '0')
 
 -- this is a global variable
 local is_system_interface = page_utils.is_system_view()
@@ -492,7 +493,9 @@ page_utils.add_menubar_section(
       entries = {
 	 {
 	    entry = page_utils.menu_entries.manage_users,
-	    hidden = not _SESSION["localuser"] or not is_admin,
+            -- Note: 'not _SESSION["localuser"]' indicates that this is an external
+            -- user (e.g. LDAP), in that case allow users management if fallback is enabled.
+	    hidden = not is_admin or (not _SESSION["localuser"] and not has_local_auth),
 	    url = '/lua/admin/users.lua',
 	 },
 	 {
@@ -965,8 +968,6 @@ if (info["pro.systemid"] and (info["pro.systemid"] ~= "")) then
 	 print('<li class="nav-item nav-link"><a href="https://shop.ntop.org"><span class="badge badge-warning">')
 	 print(i18n("about.upgrade_to_professional")..' <i class="fas fa-external-link-alt"></i>')
 	 print('</span></a></li>')
-      else
-	 print('<li class="nav-item nav-link"><span class="badge badge-warning">'..i18n("about.forced_community_notification_short")..'</span></li>')
       end
    end
 end
