@@ -355,7 +355,7 @@ end
 
 -- #################################
 
-function alert_utils.getNumAlertsPerHour(what, epoch_begin, epoch_end, alert_type, alert_severity)
+function alert_utils.getNumAlertsPerHour(what, epoch_begin, epoch_end, alert_type, alert_severity, host_info)
    local opts = {
       epoch_begin = epoch_begin,
       epoch_end = epoch_end,
@@ -363,6 +363,12 @@ function alert_utils.getNumAlertsPerHour(what, epoch_begin, epoch_end, alert_typ
       alert_severity = alert_severity,
    }
 
+   if host_info and host_info.host then
+      local entity_info = alerts_api.hostAlertEntity(host_info.host, host_info.vlan)
+      opts.entity = entity_info.alert_entity.entity_id
+      opts.entity_val = entity_info.alert_entity_val
+   end
+
    return performAlertsQuery("select (alert_tstamp - alert_tstamp % 3600) as hour, count(*) count", what, opts, nil, "hour")
 end
 
@@ -1828,7 +1834,6 @@ function alert_utils.formatAlertNotification(notif, options)
 
    if options.nohtml then
       msg = msg .. noHtml(alert_message)
-      msg = msg:gsub('&nbsp;', "")
    else
       msg = msg .. alert_message
    end
