@@ -125,13 +125,13 @@ end
 -- @brief Lists the all available plugins
 -- @returns a sorted table with plugins as values.
 -- @notes Plugins must be loaded based according to the sort order to honor dependencies
-local function listPlugins()
+local function listPlugins(community_plugins_only)
    local plugins = {}
    local plugins_with_deps = {}
    local rv = {}
    local source_dirs = {{"community", plugins_utils.COMMUNITY_SOURCE_DIR}}
 
-   if ntop.isPro() then
+   if not community_plugins_only and ntop.isPro() then
       source_dirs[#source_dirs + 1] = {"pro", plugins_utils.PRO_SOURCE_DIR}
 
       if ntop.isEnterpriseM() then
@@ -535,7 +535,7 @@ end
 -- other threads to see intermediate states and half-populated directories.
 function plugins_utils.loadPlugins(community_plugins_only)
   local locales_utils = require("locales_utils")
-  local plugins = listPlugins()
+  local plugins = listPlugins(community_plugins_only)
   local loaded_plugins = {}
   local locales = {}
   local path_map = {}
@@ -780,14 +780,14 @@ function plugins_utils.hasAlerts(ifid, options)
   local alert_utils = require("alert_utils")
 
   local opts = table.merge(options, {ifid = ifid})
-  local old_iface = iface
+  local old_ifid = interface.getId()
   local rv
   interface.select(ifid)
 
   rv = (areAlertsEnabled() and
     (alert_utils.hasAlerts("historical", alert_utils.getTabParameters(opts, "historical")) or
 	alert_utils.hasAlerts("engaged", alert_utils.getTabParameters(opts, "engaged"))))
-  interface.select(old_iface)
+  interface.select(''..old_ifid)
   return(rv)
 end
 
